@@ -2,41 +2,35 @@
 """Beatles Dataset Loader
 
 The Beatles Dataset includes beat and metric position, chord, key, and segmentation
-annotations for 179 Beatles songs. Details can be found in http://matthiasmauch.net/_pdf/mauch_omp_2009.pdf
-
-
-Attributes:
-    DATASET_DIR (str): The directory name for Beatles dataset. Set to `'Beatles'`.
-
-    DATA.index (dict): {track_id: track_data}.
-        track_data is a jason data loaded from `index/`
-
-    ANNOTATIONS_REMOTE (RemoteFileMetadata (namedtuple)): metadata
-        of Beatles dataset. It includes the annotation file name, annotation
-        file url, and checksum of the file.
+annotations for 179 Beatles songs. Details can be found in http://matthiasmauch.net/_pdf/mauch_omp_2009.pdf and
+http://isophonics.net/content/reference-annotations-beatles.
 
 """
+
 import csv
 import librosa
-import os
 import numpy as np
+import os
 
-import mirdata.utils as utils
-import mirdata.download_utils as download_utils
-import mirdata.jams_utils as jams_utils
+from mirdata import download_utils
+from mirdata import jams_utils
+from mirdata import track
+from mirdata import utils
 
 DATASET_DIR = 'Beatles'
-ANNOTATIONS_REMOTE = download_utils.RemoteFileMetadata(
-    filename='The Beatles Annotations.tar.gz',
-    url='http://isophonics.net/files/annotations/The%20Beatles%20Annotations.tar.gz',
-    checksum='62425c552d37c6bb655a78e4603828cc',
-    destination_dir='annotations',
-)
+REMOTES = {
+    'annotations': download_utils.RemoteFileMetadata(
+        filename='The Beatles Annotations.tar.gz',
+        url='http://isophonics.net/files/annotations/The%20Beatles%20Annotations.tar.gz',
+        checksum='62425c552d37c6bb655a78e4603828cc',
+        destination_dir='annotations',
+    )
+}
 
 DATA = utils.LargeData('beatles_index.json')
 
 
-class Track(object):
+class Track(track.Track):
     """Beatles track class
 
     Args:
@@ -45,13 +39,13 @@ class Track(object):
             If `None`, looks for the data in the default directory, `~/mir_datasets`
 
     Attributes:
-        track_id (str): track id
         audio_path (str): track audio path
+        beats_path (str): beat annotation path
+        chords_path (str): chord annotation path
+        keys_path (str): key annotation path
+        sections_path (str): sections annotation path
         title (str): title of the track
-        beats (BeatData): beat annotation
-        chords (ChordData): chords annotation
-        key (KeyData): key annotation
-        sections (SectionData): sections annotation
+        track_id (str): track id
 
     """
 
@@ -66,55 +60,49 @@ class Track(object):
 
         self._data_home = data_home
         self._track_paths = DATA.index[track_id]
-
+        self.beats_path = utils.none_path_join(
+            [self._data_home, self._track_paths['beat'][0]]
+        )
+        self.chords_path = os.path.join(self._data_home, self._track_paths['chords'][0])
+        self.keys_path = utils.none_path_join(
+            [self._data_home, self._track_paths['keys'][0]]
+        )
+        self.sections_path = os.path.join(
+            self._data_home, self._track_paths['sections'][0]
+        )
         self.audio_path = os.path.join(self._data_home, self._track_paths['audio'][0])
 
         self.title = os.path.basename(self._track_paths['sections'][0]).split('.')[0]
 
-    def __repr__(self):
-        repr_string = (
-            "Beatles Track(track_id={}, audio_path={}, title={}, "
-            + "beats=BeatData('beat_times, 'beat_positions'), "
-            + "chords=ChordData('intervals', 'labels'), "
-            + "key=KeyData('start_times', 'end_times', 'keys'), "
-            + "sections=SectionData('intervals', 'labels'))"
-        )
-        return repr_string.format(self.track_id, self.audio_path, self.title)
-
     @utils.cached_property
     def beats(self):
-        if not self._track_paths['beat'][0] is None:
-            return _load_beats(
-                os.path.join(self._data_home, self._track_paths['beat'][0])
-            )
-        return None
+        """BeatData: human-labeled beat annotation"""
+        return load_beats(self.beats_path)
 
     @utils.cached_property
     def chords(self):
-        return _load_chords(
-            os.path.join(self._data_home, self._track_paths['chords'][0])
-        )
+        """ChordData: chord annotation"""
+        return load_chords(self.chords_path)
 
     @utils.cached_property
     def key(self):
-        if not self._track_paths['keys'][0] is None:
-            return _load_key(
-                os.path.join(self._data_home, self._track_paths['keys'][0])
-            )
-        return None
+        """KeyData: key annotation"""
+        return load_key(self.keys_path)
 
     @utils.cached_property
     def sections(self):
-        return _load_sections(
-            os.path.join(self._data_home, self._track_paths['sections'][0])
-        )
+        """SectionData: section annotation"""
+        return load_sections(self.sections_path)
 
     @property
     def audio(self):
-        return librosa.load(self.audio_path, sr=None, mono=True)
+        """(np.ndarray, float): audio signal, sample rate"""
+        return load_audio(self.audio_path)
 
     def to_jams(self):
+        """Jams: the track's data in jams format"""
         return jams_utils.jams_converter(
+            audio_path=self.audio_path,
             beat_data=[(self.beats, None)],
             section_data=[(self.sections, None)],
             chord_data=[(self.chords, None)],
@@ -123,14 +111,34 @@ class Track(object):
         )
 
 
-def download(data_home=None, force_overwrite=False):
-    """Download the Beatles Dataset (annotations).
-    The audio files are not provided due to the copyright.
+def load_audio(audio_path):
+    """Load a Beatles audio file.
 
     Args:
-        data_home (str): Local path where the dataset is stored.
+        audio_path (str): path to audio file
+
+    Returns:
+        y (np.ndarray): the mono audio signal
+        sr (float): The sample rate of the audio file
+
+    """
+    if not os.path.exists(audio_path):
+        raise IOError("audio_path {} does not exist".format(audio_path))
+    return librosa.load(audio_path, sr=None, mono=True)
+
+
+def download(data_home=None, force_overwrite=False, cleanup=True):
+    """Download the Beatles Dataset (annotations).
+    The audio files are not provided due to copyright issues.
+
+    Args:
+        data_home (str):
+            Local path where the dataset is stored.
             If `None`, looks for the data in the default directory, `~/mir_datasets`
-        force_overwrite (bool): Whether to overwrite the existing downloaded data
+        force_overwrite (bool):
+            Whether to overwrite the existing downloaded data
+        cleanup (bool):
+            Whether to delete the zip/tar file after extracting.
 
     """
 
@@ -152,9 +160,10 @@ def download(data_home=None, force_overwrite=False):
 
     download_utils.downloader(
         data_home,
-        tar_downloads=[ANNOTATIONS_REMOTE],
+        remotes=REMOTES,
         info_message=download_message,
         force_overwrite=force_overwrite,
+        cleanup=cleanup,
     )
 
 
@@ -210,16 +219,22 @@ def load(data_home=None):
     return beatles_data
 
 
-def _load_beats(beats_path):
-    """Private function to load Beatles format beat data from a file
+def load_beats(beats_path):
+    """Load Beatles format beat data from a file
 
     Args:
-        beats_path (str):
+        beats_path (str): path to beat annotation file
+
+    Returns:
+        (utils.BeatData): loaded beat data
 
     """
-    if beats_path is None or not os.path.exists(beats_path):
+    if beats_path is None:
         return None
 
+    if not os.path.exists(beats_path):
+        raise IOError("beats_path {} does not exist".format(beats_path))
+
     beat_times, beat_positions = [], []
     with open(beats_path, 'r') as fhandle:
         dialect = csv.Sniffer().sniff(fhandle.read(1024))
@@ -238,16 +253,22 @@ def _load_beats(beats_path):
     return beat_data
 
 
-def _load_chords(chords_path):
-    """Private function to load Beatles format chord data from a file
+def load_chords(chords_path):
+    """Load Beatles format chord data from a file
 
     Args:
-        chords_path (str):
+        chords_path (str): path to chord annotation file
+
+    Returns:
+        (utils.ChordData): loaded chord data
 
     """
-    if chords_path is None or not os.path.exists(chords_path):
+    if chords_path is None:
         return None
 
+    if not os.path.exists(chords_path):
+        raise IOError("chords_path {} does not exist".format(chords_path))
+
     start_times, end_times, chords = [], [], []
     with open(chords_path, 'r') as f:
         dialect = csv.Sniffer().sniff(f.read(1024))
@@ -263,18 +284,24 @@ def _load_chords(chords_path):
     return chord_data
 
 
-def _load_key(key_path):
-    """Private function to load Beatles format key data from a file
+def load_key(keys_path):
+    """Load Beatles format key data from a file
 
     Args:
-        key_path (str):
+        keys_path (str): path to key annotation file
+
+    Returns:
+        (utils.KeyData): loaded key data
 
     """
-    if key_path is None or not os.path.exists(key_path):
+    if keys_path is None:
         return None
 
+    if not os.path.exists(keys_path):
+        raise IOError("keys_path {} does not exist".format(keys_path))
+
     start_times, end_times, keys = [], [], []
-    with open(key_path, 'r') as fhandle:
+    with open(keys_path, 'r') as fhandle:
         reader = csv.reader(fhandle, delimiter='\t')
         for line in reader:
             if line[2] == 'Key':
@@ -287,16 +314,22 @@ def _load_key(key_path):
     return key_data
 
 
-def _load_sections(sections_path):
-    """Private function to load Beatles format sections data from a file
+def load_sections(sections_path):
+    """Load Beatles format section data from a file
 
     Args:
-        sections_path (str):
+        sections_path (str): path to section annotation file
+
+    Returns:
+        (utils.SectionData): loaded section data
 
     """
-    if sections_path is None or not os.path.exists(sections_path):
+    if sections_path is None:
         return None
 
+    if not os.path.exists(sections_path):
+        raise IOError("sections_path {} does not exist".format(sections_path))
+
     start_times, end_times, sections = [], [], []
     with open(sections_path, 'r') as fhandle:
         reader = csv.reader(fhandle, delimiter='\t')
@@ -312,7 +345,7 @@ def _load_sections(sections_path):
 
 def _fix_newpoint(beat_positions):
     """Fills in missing beat position labels by inferring the beat position
-        from neighboring beats.
+    from neighboring beats.
 
     """
     while np.any(beat_positions == 'New Point'):
