@@ -1,25 +1,15 @@
 # -*- coding: utf-8 -*-
 """SALAMI Dataset Loader
 
-SALAMI Dataset.
+The SALAMI dataset contains Structural Annotations of a Large Amount of Music
+Information: the public portion contains over 2200 annotations of over 1300
+unique tracks.
 
-We are using the **corrected** version of the 2.0 annotations:
+NB: mirdata relies on the **corrected** version of the 2.0 annotations:
 Details can be found at https://github.com/bmcfee/salami-data-public/tree/hierarchy-corrections and
 https://github.com/DDMAL/salami-data-public/pull/15.
 
-Attributes:
-    DIR (str): The directory name for SALAMI dataset. Set to `'Salami'`.
-
-    DATA.index (dict): {track_id: track_data}.
-        track_data is a jason data loaded from `index/`
-
-    DATA.metadata (None): (todo?)
-
-    ANNOT_REMOTE (RemoteFileMetadata (namedtuple)): metadata
-        of SALAMI dataset. It includes the annotation file name, annotation
-        file url, and checksum of the file.
-
-
+For more details, please visit: https://github.com/DDMAL/salami-data-public
 """
 import csv
 import librosa
@@ -27,17 +17,21 @@ import logging
 import numpy as np
 import os
 
-import mirdata.utils as utils
-import mirdata.download_utils as download_utils
-import mirdata.jams_utils as jams_utils
+from mirdata import download_utils
+from mirdata import jams_utils
+from mirdata import track
+from mirdata import utils
 
 DATASET_DIR = 'Salami'
-ANNOTATIONS_REMOTE = download_utils.RemoteFileMetadata(
-    filename='salami-data-public-hierarchy-corrections.zip',
-    url='https://github.com/bmcfee/salami-data-public/archive/hierarchy-corrections.zip',
-    checksum='194add2601c09a7279a7433288de81fd',
-    destination_dir=None,
-)
+
+REMOTES = {
+    'annotations': download_utils.RemoteFileMetadata(
+        filename='salami-data-public-hierarchy-corrections.zip',
+        url='https://github.com/bmcfee/salami-data-public/archive/hierarchy-corrections.zip',
+        checksum='194add2601c09a7279a7433288de81fd',
+        destination_dir=None,
+    )
+}
 
 
 def _load_metadata(data_home):
@@ -88,31 +82,30 @@ def _load_metadata(data_home):
 DATA = utils.LargeData('salami_index.json', _load_metadata)
 
 
-class Track(object):
-    """SALAMI Track class
+class Track(track.Track):
+    """salami Track class
 
     Args:
         track_id (str): track id of the track
-        data_home (str): Local path where the dataset is stored.
+        data_home (str): Local path where the dataset is stored. default=None
             If `None`, looks for the data in the default directory, `~/mir_datasets`
 
     Attributes:
-        track_id (str): track id
-        audio_path (str): audio path of the track
-        source
-        annotator_1_id
-        annotator_2_id
-        duration: duration of the track
-        title: title of the track
-        artist
-        annotator_1_time
-        annotator_2-time
-        broad_genre
-        genre:
-        sections_annotator_1_uppercase: annotation
-        sections_annotator_1_lowercase: annotation
-        sections_annotator_2_uppercase: annotation
-        sections_annotator_2_lowercase: annotation
+        annotator_1_id (str): number that identifies annotator 1
+        annotator_1_time (str): time that the annotator 1 took to complete the annotation
+        annotator_2_id (str): number that identifies annotator 1
+        annotator_2_time (str): time that the annotator 1 took to complete the annotation
+        artist (str): song artist
+        audio_path (str): path to the audio file
+        broad_genre (str): broad genre of the song
+        duration (float): duration of song in seconds
+        genre (str): genre of the song
+        sections_annotator1_lowercase_path (str): path to annotations in hierarchy level 1 from annotator 1
+        sections_annotator1_uppercase_path (str): path to annotations in hierarchy level 0 from annotator 1
+        sections_annotator2_lowercase_path (str): path to annotations in hierarchy level 1 from annotator 2
+        sections_annotator2_uppercase_path (str): path to annotations in hierarchy level 0 from annotator 2
+        source (str): dataset or source of song
+        title (str): title of the song
 
     """
 
@@ -127,6 +120,18 @@ class Track(object):
 
         self._data_home = data_home
         self._track_paths = DATA.index[track_id]
+        self.sections_annotator1_uppercase_path = utils.none_path_join(
+            [self._data_home, self._track_paths['annotator_1_uppercase'][0]]
+        )
+        self.sections_annotator1_lowercase_path = utils.none_path_join(
+            [self._data_home, self._track_paths['annotator_1_lowercase'][0]]
+        )
+        self.sections_annotator2_uppercase_path = utils.none_path_join(
+            [self._data_home, self._track_paths['annotator_2_uppercase'][0]]
+        )
+        self.sections_annotator2_lowercase_path = utils.none_path_join(
+            [self._data_home, self._track_paths['annotator_2_lowercase'][0]]
+        )
 
         metadata = DATA.metadata(data_home)
         if metadata is not None and track_id in metadata.keys():
@@ -157,70 +162,43 @@ class Track(object):
         self.broad_genre = self._track_metadata['class']
         self.genre = self._track_metadata['genre']
 
-    def __repr__(self):
-        repr_string = (
-            "Salami Track(track_id={}, audio_path={}, source={}, "
-            + "title={}, artist={}, duration={}, annotator_1_id={}, "
-            + "annotator_2_id={}, annotator_1_time={}, annotator_2_time={}, "
-            + "broad_genre={}, genre={}, "
-            + "sections_annotator_1_uppercase=SectionData('intervals', 'labels'), "
-            + "sections_annotator_1_lowercase=SectionData('intervals', 'labels'), "
-            + "sections_annotator_2_uppercase=SectionData('intervals', 'labels'), "
-            + "sections_annotator_2_lowercase=SectionData('intervals', 'labels'))"
-        )
-        return repr_string.format(
-            self.track_id,
-            self.audio_path,
-            self.source,
-            self.title,
-            self.artist,
-            self.duration,
-            self.annotator_1_id,
-            self.annotator_2_id,
-            self.annotator_1_time,
-            self.annotator_2_time,
-            self.broad_genre,
-            self.genre,
-        )
-
     @utils.cached_property
     def sections_annotator_1_uppercase(self):
-        if self._track_paths['annotator_1_uppercase'][0] is None:
+        """SectionData: annotations in hierarchy level 0 from annotator 1"""
+        if self.sections_annotator1_uppercase_path is None:
             return None
-        return _load_sections(
-            os.path.join(self._data_home, self._track_paths['annotator_1_uppercase'][0])
-        )
+        return load_sections(self.sections_annotator1_uppercase_path)
 
     @utils.cached_property
     def sections_annotator_1_lowercase(self):
-        if self._track_paths['annotator_1_lowercase'][0] is None:
+        """SectionData: annotations in hierarchy level 1 from annotator 1"""
+        if self.sections_annotator1_lowercase_path is None:
             return None
-        return _load_sections(
-            os.path.join(self._data_home, self._track_paths['annotator_1_lowercase'][0])
-        )
+        return load_sections(self.sections_annotator1_lowercase_path)
 
     @utils.cached_property
     def sections_annotator_2_uppercase(self):
-        if self._track_paths['annotator_2_uppercase'][0] is None:
+        """SectionData: annotations in hierarchy level 0 from annotator 2"""
+        if self.sections_annotator2_uppercase_path is None:
             return None
-        return _load_sections(
-            os.path.join(self._data_home, self._track_paths['annotator_2_uppercase'][0])
-        )
+        return load_sections(self.sections_annotator2_uppercase_path)
 
     @utils.cached_property
     def sections_annotator_2_lowercase(self):
-        if self._track_paths['annotator_2_lowercase'][0] is None:
+        """SectionData: annotations in hierarchy level 1 from annotator 2"""
+        if self.sections_annotator2_lowercase_path is None:
             return None
-        return _load_sections(
-            os.path.join(self._data_home, self._track_paths['annotator_2_lowercase'][0])
-        )
+        return load_sections(self.sections_annotator2_lowercase_path)
 
     @property
     def audio(self):
-        return librosa.load(self.audio_path, sr=None, mono=True)
+        """(np.ndarray, float): audio signal, sample rate"""
+        return load_audio(self.audio_path)
 
     def to_jams(self):
+        """Jams: the track's data in jams format"""
         return jams_utils.jams_converter(
+            audio_path=self.audio_path,
             multi_section_data=[
                 (
                     [
@@ -241,15 +219,35 @@ class Track(object):
         )
 
 
-def download(data_home=None, force_overwrite=False):
+def load_audio(audio_path):
+    """Load a Salami audio file.
+
+    Args:
+        audio_path (str): path to audio file
+
+    Returns:
+        y (np.ndarray): the mono audio signal
+        sr (float): The sample rate of the audio file
+
+    """
+    if not os.path.exists(audio_path):
+        raise IOError("audio_path {} does not exist".format(audio_path))
+
+    return librosa.load(audio_path, sr=None, mono=True)
+
+
+def download(data_home=None, force_overwrite=False, cleanup=True):
     """Download SALAMI Dataset (annotations).
     The audio files are not provided.
 
     Args:
-        data_home (str): Local path where the dataset is stored.
+        data_home (str):
+            Local path where the dataset is stored.
             If `None`, looks for the data in the default directory, `~/mir_datasets`
-
-        force_overwrite (bool): whether to overwrite the existing downloaded data
+        force_overwrite (bool):
+            Whether to overwrite the existing downloaded data
+        cleanup (bool):
+            Whether to delete the zip/tar file after extracting.
 
     """
     if data_home is None:
@@ -269,9 +267,10 @@ def download(data_home=None, force_overwrite=False):
 
     download_utils.downloader(
         data_home,
-        zip_downloads=[ANNOTATIONS_REMOTE],
+        remotes=REMOTES,
         info_message=info_message,
         force_overwrite=force_overwrite,
+        cleanup=cleanup,
     )
 
 
@@ -327,10 +326,13 @@ def load(data_home=None):
     return salami_data
 
 
-def _load_sections(sections_path):
-    if sections_path is None or not os.path.exists(sections_path):
+def load_sections(sections_path):
+    if sections_path is None:
         return None
 
+    if not os.path.exists(sections_path):
+        raise IOError("sections_path {} does not exist".format(sections_path))
+
     times = []
     secs = []
     with open(sections_path, 'r') as fhandle:
